@@ -7,5 +7,6 @@ VERSION = __version__.split(".")
 
 from .git_access import *
 from .pretty_fit import fitTable, prettyPolyFit
+from .create_pdf import notebook_to_pdf
 
-__all__ = ["local_repository", "fitTable", "prettyPolyFit"]
\ No newline at end of file
+__all__ = ["local_repository", "fitTable", "prettyPolyFit", "notebook_to_pdf"]
\ No newline at end of file
